@@ -6,7 +6,7 @@
 """
 from html import unescape
 from pathlib import Path
-from re import split as re_SPLIT, search, sub
+from re import split, search, sub
 from shutil import rmtree
 from typing import Union
 from zipfile import ZipFile
@@ -18,9 +18,9 @@ def get_ele_txt(e) -> str:
     :return: 元素内所有文本
     """
     # 前面无须换行的元素
-    nowrap_list = ('br', 'sub', 'em', 'strong', 'a', 'font', 'b', 'span', 's', 'i', 'del', 'ins', 'img', 'td', 'th',
-                   'abbr', 'bdi', 'bdo', 'cite', 'code', 'data', 'dfn', 'kbd', 'mark', 'q', 'rp', 'rt', 'ruby',
-                   'samp', 'small', 'sub', 'time', 'u', 'var', 'wbr', 'button', 'slot', 'content')
+    nowrap_list = ('br', 'sub', 'sup', 'em', 'strong', 'a', 'font', 'b', 'span', 's', 'i', 'del', 'ins', 'img', 'td',
+                   'th', 'abbr', 'bdi', 'bdo', 'cite', 'code', 'data', 'dfn', 'kbd', 'mark', 'q', 'rp', 'rt', 'ruby',
+                   'samp', 'small', 'time', 'u', 'var', 'wbr', 'button', 'slot', 'content')
     # 后面添加换行的元素
     wrap_after_list = ('p', 'div', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'ol', 'li', 'blockquote', 'header',
                        'footer', 'address' 'article', 'aside', 'main', 'nav', 'section', 'figcaption', 'summary')
@@ -51,7 +51,7 @@ def get_ele_txt(e) -> str:
                     str_list.append(el)
 
                 else:
-                    if sub('[ \n\t]', '', el) != '':  # 字符除了回车和空格还有其它内容
+                    if sub('[ \n\t\r]', '', el) != '':  # 字符除了回车和空格还有其它内容
                         txt = el
                         if not pre:
                             txt = txt.replace('\n', ' ').strip(' ')
@@ -79,6 +79,33 @@ def get_ele_txt(e) -> str:
     return format_html(re_str)
 
 
+def get_loc(loc: Union[tuple, str], translate_css: bool = False) -> tuple:
+    """接收selenium定位元组或本库定位语法，转换为标准定位元组，可翻译css selector为xpath  \n
+    :param loc: selenium定位元组或本库定位语法
+    :param translate_css: 是否翻译css selector为xpath
+    :return: DrissionPage定位元组
+    """
+    if isinstance(loc, tuple):
+        loc = translate_loc(loc)
+
+    elif isinstance(loc, str):
+        loc = str_to_loc(loc)
+
+    else:
+        raise TypeError('loc参数只能是tuple或str。')
+
+    if loc[0] == 'css selector' and translate_css:
+        from lxml.cssselect import CSSSelector, ExpressionError
+        try:
+            path = str(CSSSelector(loc[1], translator='html').path)
+            path = path[20:] if path.startswith('descendant-or-self::') else path
+            loc = 'xpath', path
+        except ExpressionError:
+            pass
+
+    return loc
+
+
 def str_to_loc(loc: str) -> tuple:
     """处理元素查找语句                                                                    \n
     查找方式：属性、tag name及属性、文本、xpath、css selector、id、class                      \n
@@ -86,7 +113,6 @@ def str_to_loc(loc: str) -> tuple:
     """
     loc_by = 'xpath'
 
-    # .和#替换为class和id查找
     if loc.startswith('.'):
         if loc.startswith(('.=', '.:',)):
             loc = loc.replace('.', '@class', 1)
@@ -105,61 +131,149 @@ def str_to_loc(loc: str) -> tuple:
     elif loc.startswith(('tx:', 'tx=')):
         loc = f'text{loc[2:]}'
 
-    # 根据属性查找
-    if loc.startswith('@'):
-        r = re_SPLIT(r'([:=])', loc[1:], maxsplit=1)
-        if len(r) == 3:
-            mode = 'exact' if r[1] == '=' else 'fuzzy'
-            loc_str = _make_xpath_str('*', f'@{r[0]}', r[2], mode)
-        else:
-            loc_str = f'//*[@{loc[1:]}]'
+    # ------------------------------------------------------------------
+    # 多属性查找
+    if loc.startswith('@@') and loc != '@@':
+        loc_str = _make_multi_xpath_str('*', loc)
+
+    # 单属性查找
+    elif loc.startswith('@') and loc != '@':
+        loc_str = _make_single_xpath_str('*', loc)
 
     # 根据tag name查找
-    elif loc.startswith(('tag:', 'tag=')):
-        if '@' not in loc[4:]:
+    elif loc.startswith(('tag:', 'tag=')) and loc not in ('tag:', 'tag='):
+        at_ind = loc.find('@')
+        if at_ind == -1:
             loc_str = f'//*[name()="{loc[4:]}"]'
         else:
-            at_lst = loc[4:].split('@', maxsplit=1)
-            r = re_SPLIT(r'([:=])', at_lst[1], maxsplit=1)
-            if len(r) == 3:
-                mode = 'exact' if r[1] == '=' else 'fuzzy'
-                arg_str = 'text()' if r[0] in ('text()', 'tx()') else f'@{r[0]}'
-                loc_str = _make_xpath_str(at_lst[0], arg_str, r[2], mode)
+            if loc[at_ind:].startswith('@@'):
+                loc_str = _make_multi_xpath_str(loc[4:at_ind], loc[at_ind:])
             else:
-                loc_str = f'//*[name()="{at_lst[0]}" and @{r[0]}]'
+                loc_str = _make_single_xpath_str(loc[4:at_ind], loc[at_ind:])
 
     # 根据文本查找
-    elif loc.startswith(('text:', 'text=')):
-        if len(loc) > 5:
-            mode = 'exact' if loc[4] == '=' else 'fuzzy'
-            loc_str = _make_xpath_str('*', 'text()', loc[5:], mode)
-        else:
-            loc_str = '//*[not(text())]'
+    elif loc.startswith('text='):
+        loc_str = f'//*[.={_make_search_str(loc[5:])}]'
+    elif loc.startswith('text:') and loc != 'text:':
+        loc_str = f'//*/text()[contains(., {_make_search_str(loc[5:])})]/..'
 
     # 用xpath查找
-    elif loc.startswith(('xpath:', 'xpath=')):
+    elif loc.startswith(('xpath:', 'xpath=')) and loc not in ('xpath:', 'xpath='):
         loc_str = loc[6:]
-    elif loc.startswith(('x:', 'x=')):
+    elif loc.startswith(('x:', 'x=')) and loc not in ('x:', 'x='):
         loc_str = loc[2:]
 
     # 用css selector查找
-    elif loc.startswith(('css:', 'css=')):
+    elif loc.startswith(('css:', 'css=')) and loc not in ('css:', 'css='):
         loc_by = 'css selector'
         loc_str = loc[4:]
-    elif loc.startswith(('c:', 'c=')):
+    elif loc.startswith(('c:', 'c=')) and loc not in ('c:', 'c='):
         loc_by = 'css selector'
         loc_str = loc[2:]
 
     # 根据文本模糊查找
+    elif loc:
+        loc_str = f'//*/text()[contains(., {_make_search_str(loc)})]/..'
     else:
-        if loc:
-            loc_str = _make_xpath_str('*', 'text()', loc, 'fuzzy')
-        else:
-            loc_str = '//*[not(text())]'
+        loc_str = '//*'
 
     return loc_by, loc_str
 
 
+def _make_single_xpath_str(tag: str, text: str) -> str:
+    """生成xpath语句                  \n
+    :param tag: 标签名
+    :param text: 待处理的字符串
+    :return: xpath字符串
+    """
+    arg_list = [] if tag == '*' else [f'name()="{tag}"']
+    arg_str = txt_str = ''
+
+    if text == '@':
+        arg_str = 'not(@*)'
+
+    else:
+        r = split(r'([:=])', text, maxsplit=1)
+        len_r = len(r)
+        len_r0 = len(r[0])
+        if len_r != 3 and len_r0 > 1:
+            arg_str = 'normalize-space(text())' if r[0] in ('@text()', '@tx()') else f'{r[0]}'
+
+        elif len_r == 3 and len_r0 > 1:
+            if r[1] == '=':  # 精确查找
+                arg = '.' if r[0] in ('@text()', '@tx()') else r[0]
+                arg_str = f'{arg}={_make_search_str(r[2])}'
+
+            else:  # 模糊查找
+                if r[0] in ('@text()', '@tx()'):
+                    txt_str = f'/text()[contains(., {_make_search_str(r[2])})]/..'
+                    arg_str = ''
+                else:
+                    arg_str = f"contains({r[0]},{_make_search_str(r[2])})"
+
+    if arg_str:
+        arg_list.append(arg_str)
+    arg_str = ' and '.join(arg_list)
+    return f'//*[{arg_str}]{txt_str}' if arg_str else f'//*{txt_str}'
+
+
+def _make_multi_xpath_str(tag: str, text: str) -> str:
+    """生成多属性查找的xpath语句                    \n
+    :param tag: 标签名
+    :param text: 待处理的字符串
+    :return: xpath字符串
+    """
+    arg_list = [] if tag == '*' else [f'name()="{tag}"']
+    args = text.split('@@')
+
+    for arg in args[1:]:
+        r = split(r'([:=])', arg, maxsplit=1)
+        arg_str = ''
+        len_r = len(r)
+
+        if not r[0]:  # 不查询任何属性
+            arg_str = 'not(@*)'
+
+        else:
+            r[0], ignore = (r[0][1:], True) if r[0][0] == '-' else (r[0], None)  # 是否去除某个属性
+
+            if len_r != 3:  # 只有属性名没有属性内容，查询是否存在该属性
+                arg_str = 'normalize-space(text())' if r[0] in ('text()', 'tx()') else f'@{r[0]}'
+
+            elif len_r == 3:  # 属性名和内容都有
+                arg = '.' if r[0] in ('text()', 'tx()') else f'@{r[0]}'
+                if r[1] == '=':
+                    arg_str = f'{arg}={_make_search_str(r[2])}'
+                else:
+                    arg_str = f'contains({arg},{_make_search_str(r[2])})'
+
+            if arg_str and ignore:
+                arg_str = f'not({arg_str})'
+
+        if arg_str:
+            arg_list.append(arg_str)
+
+    arg_str = ' and '.join(arg_list)
+    return f'//*[{arg_str}]' if arg_str else f'//*'
+
+
+def _make_search_str(search_str: str) -> str:
+    """将"转义，不知何故不能直接用 \ 来转义 \n
+    :param search_str: 查询字符串
+    :return: 把"转义后的字符串
+    """
+    parts = search_str.split('"')
+    parts_num = len(parts)
+    search_str = 'concat('
+
+    for key, i in enumerate(parts):
+        search_str += f'"{i}"'
+        search_str += ',' + '\'"\',' if key < parts_num - 1 else ''
+
+    search_str += ',"")'
+    return search_str
+
+
 def translate_loc(loc: tuple) -> tuple:
     """把By类型的loc元组转换为css selector或xpath类型的  \n
     :param loc: By类型的loc元组
@@ -201,48 +315,6 @@ def translate_loc(loc: tuple) -> tuple:
     return loc_by, loc_str
 
 
-def _make_xpath_str(tag: str, arg: str, val: str, mode: str = 'fuzzy') -> str:
-    """生成xpath语句                                          \n
-    :param tag: 标签名
-    :param arg: 属性名
-    :param val: 属性值
-    :param mode: 'exact' 或 'fuzzy'，对应精确或模糊查找
-    :return: xpath字符串
-    """
-    tag_name = '' if tag == '*' else f'name()="{tag}" and '
-
-    if mode == 'exact':
-        return f'//*[{tag_name}{arg}={_make_search_str(val)}]'
-
-    elif mode == 'fuzzy':
-        if arg == 'text()':
-            tag_name = '' if tag == '*' else f'{tag}/'
-            return f'//{tag_name}text()[contains(., {_make_search_str(val)})]/..'
-        else:
-            return f"//*[{tag_name}contains({arg},{_make_search_str(val)})]"
-
-    else:
-        raise ValueError("mode参数只能是'exact'或'fuzzy'。")
-
-
-def _make_search_str(search_str: str) -> str:
-    """将"转义，不知何故不能直接用 \ 来转义 \n
-    :param search_str: 查询字符串
-    :return: 把"转义后的字符串
-    """
-    parts = search_str.split('"')
-    parts_num = len(parts)
-    search_str = 'concat('
-
-    for key, i in enumerate(parts):
-        search_str += f'"{i}"'
-        search_str += ',' + '\'"\',' if key < parts_num - 1 else ''
-
-    search_str += ',"")'
-
-    return search_str
-
-
 def format_html(text: str) -> str:
     """处理html编码字符             \n
     :param text: html文本
