@@ -16,7 +16,7 @@ from selenium.webdriver.support import expected_conditions as ec
 from selenium.webdriver.support.wait import WebDriverWait
 
 from .base import DrissionElement, BaseElement
-from .common import str_to_loc, get_usable_path, translate_loc, format_html, get_ele_txt
+from .common import str_to_loc, get_usable_path, format_html, get_ele_txt, get_loc
 from .session_element import make_session_ele
 
 
@@ -24,10 +24,14 @@ class DriverElement(DrissionElement):
     """driver模式的元素对象，包装了一个WebElement对象，并封装了常用功能"""
 
     def __init__(self, ele: WebElement, page=None):
+        """初始化对象                          \n
+        :param ele: 被包装的WebElement元素
+        :param page: 元素所在页面
+        """
         super().__init__(ele, page)
         self._select = None
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
         return f'<DriverElement {self.tag} {" ".join(attrs)}>'
 
@@ -87,19 +91,6 @@ class DriverElement(DrissionElement):
         """返回未格式化处理的元素内文本"""
         return self.inner_ele.get_attribute('innerText')
 
-    @property
-    def parent(self):
-        """返回父级元素"""
-        return self.parents()
-
-    def parents(self, num: int = 1):
-        """返回上面第num级父元素              \n
-        :param num: 第几级父元素
-        :return: DriverElement对象
-        """
-        loc = 'xpath', f'.{"/.." * num}'
-        return self.ele(loc, timeout=0)
-
     def attr(self, attr: str) -> str:
         """获取attribute属性值            \n
         :param attr: 属性名
@@ -119,9 +110,9 @@ class DriverElement(DrissionElement):
     def ele(self,
             loc_or_str: Union[Tuple[str, str], str],
             timeout: float = None):
-        """返回当前元素下级符合条件的第一个元素、属性或节点文本                                      \n
+        """返回当前元素下级符合条件的第一个元素、属性或节点文本                 \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
         :return: DriverElement对象或属性、文本
         """
         return self._ele(loc_or_str, timeout)
@@ -129,21 +120,21 @@ class DriverElement(DrissionElement):
     def eles(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout: float = None):
-        """返回当前元素下级所有符合条件的子元素、属性或节点文本                                                   \n
+        """返回当前元素下级所有符合条件的子元素、属性或节点文本                 \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
         :return: DriverElement对象或属性、文本组成的列表
         """
         return self._ele(loc_or_str, timeout=timeout, single=False)
 
-    def s_ele(self, loc_or_ele=None):
+    def s_ele(self, loc_or_str: Union[Tuple[str, str], str] = None):
         """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高        \n
-        :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
+        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
-        return make_session_ele(self, loc_or_ele)
+        return make_session_ele(self, loc_or_str)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str]):
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None):
         """查找所有符合条件的元素以SessionElement列表形式返回                         \n
         :param loc_or_str: 定位符
         :return: SessionElement或属性、文本组成的列表
@@ -201,7 +192,8 @@ class DriverElement(DrissionElement):
         }
         return e(arguments[0]);
         '''
-        return self.run_script(js)
+        res_txt = self.run_script(js)
+        return f':root{res_txt}' if mode == 'css' else res_txt
 
     # -----------------driver独有属性和方法-------------------
     @property
@@ -228,14 +220,14 @@ class DriverElement(DrissionElement):
         return self.shadow_root
 
     @property
-    def before(self) -> str:
+    def pseudo_before(self) -> str:
         """返回当前元素的::before伪元素内容"""
-        return self.get_style_property('content', 'before')
+        return self.style('content', 'before')
 
     @property
-    def after(self) -> str:
+    def pseudo_after(self) -> str:
         """返回当前元素的::after伪元素内容"""
-        return self.get_style_property('content', 'after')
+        return self.style('content', 'after')
 
     @property
     def select(self):
@@ -248,6 +240,86 @@ class DriverElement(DrissionElement):
 
         return self._select
 
+    def left(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> 'DriverElement':
+        """获取网页上显示在当前元素左边的某个元素，可设置选取条件，可指定结果中第几个               \n
+        :param index: 获取第几个
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        eles = self._get_relative_eles('left', filter_loc)
+        return eles[index - 1] if index <= len(eles) else None
+
+    def right(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> 'DriverElement':
+        """获取网页上显示在当前元素右边的某个元素，可设置选取条件，可指定结果中第几个               \n
+        :param index: 获取第几个
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        eles = self._get_relative_eles('right', filter_loc)
+        return eles[index - 1] if index <= len(eles) else None
+
+    def above(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> 'DriverElement':
+        """获取网页上显示在当前元素上边的某个元素，可设置选取条件，可指定结果中第几个               \n
+        :param index: 获取第几个
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        eles = self._get_relative_eles('left', filter_loc)
+        return eles[index - 1] if index <= len(eles) else None
+
+    def below(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> 'DriverElement':
+        """获取网页上显示在当前元素下边的某个元素，可设置选取条件，可指定结果中第几个               \n
+        :param index: 获取第几个
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        eles = self._get_relative_eles('left', filter_loc)
+        return eles[index - 1] if index <= len(eles) else None
+
+    def near(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> 'DriverElement':
+        """获取网页上显示在当前元素最近的某个元素，可设置选取条件，可指定结果中第几个               \n
+        :param index: 获取第几个
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        eles = self._get_relative_eles('near', filter_loc)
+        return eles[index - 1] if index <= len(eles) else None
+
+    def lefts(self, filter_loc: Union[tuple, str] = '') -> List['DriverElement']:
+        """获取网页上显示在当前元素左边的所有元素，可设置选取条件，从近到远排列                    \n
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象组成的列表
+        """
+        return self._get_relative_eles('left', filter_loc)
+
+    def rights(self, filter_loc: Union[tuple, str] = '') -> List['DriverElement']:
+        """获取网页上显示在当前元素右边的所有元，可设置选取条件，从近到远排列                    \n
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象组成的列表
+        """
+        return self._get_relative_eles('right', filter_loc)
+
+    def aboves(self, filter_loc: Union[tuple, str] = '') -> List['DriverElement']:
+        """获取网页上显示在当前元素上边的所有元素，可设置选取条件，从近到远排列                    \n
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象组成的列表
+        """
+        return self._get_relative_eles('left', filter_loc)
+
+    def belows(self, filter_loc: Union[tuple, str] = '') -> List['DriverElement']:
+        """获取网页上显示在当前元素下边的所有元素，可设置选取条件，从近到远排列                    \n
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象组成的列表
+        """
+        return self._get_relative_eles('left', filter_loc)
+
+    def nears(self, filter_loc: Union[tuple, str] = '') -> List['DriverElement']:
+        """获取网页上显示在当前元素附近元素，可设置选取条件，从近到远排列                    \n
+        :param filter_loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象组成的列表
+        """
+        return self._get_relative_eles('near', filter_loc)
+
     def wait_ele(self,
                  loc_or_ele: Union[str, tuple, DrissionElement, WebElement],
                  mode: str,
@@ -260,10 +332,10 @@ class DriverElement(DrissionElement):
         """
         return _wait_ele(self, loc_or_ele, mode, timeout)
 
-    def get_style_property(self, style: str, pseudo_ele: str = '') -> str:
-        """返回元素样式属性值
+    def style(self, style: str, pseudo_ele: str = '') -> str:
+        """返回元素样式属性值，可获取伪元素属性值                \n
         :param style: 样式属性名称
-        :param pseudo_ele: 伪元素名称
+        :param pseudo_ele: 伪元素名称（如有）
         :return: 样式属性的值
         """
         if pseudo_ele:
@@ -279,15 +351,23 @@ class DriverElement(DrissionElement):
         :param timeout: 尝试点击的超时时间，不指定则使用父页面的超时时间
         :return: 是否点击成功
         """
+
+        def do_it() -> bool:
+            try:
+                self.inner_ele.click()
+                return True
+            except Exception:
+                return False
+
         if not by_js:
             timeout = timeout if timeout is not None else self.page.timeout
             t1 = perf_counter()
-            while perf_counter() - t1 <= timeout:
-                try:
-                    self.inner_ele.click()
-                    return True
-                except:
-                    pass
+            click = do_it()
+            while not click and perf_counter() - t1 <= timeout:
+                click = do_it()
+
+            if click:
+                return True
 
         # 若点击失败，用js方式点击
         if by_js is not False:
@@ -296,7 +376,10 @@ class DriverElement(DrissionElement):
 
         return False
 
-    def click_at(self, x: Union[int, str] = None, y: Union[int, str] = None, by_js=False) -> None:
+    def click_at(self,
+                 x: Union[int, str] = None,
+                 y: Union[int, str] = None,
+                 by_js: bool = False) -> None:
         """带偏移量点击本元素，相对于左上角坐标。不传入x或y值时点击元素中点    \n
         :param x: 相对元素左上角坐标的x轴偏移量
         :param y: 相对元素左上角坐标的y轴偏移量
@@ -338,18 +421,24 @@ class DriverElement(DrissionElement):
         from selenium.webdriver import ActionChains
         ActionChains(self.page.driver).move_to_element_with_offset(self.inner_ele, x, y).context_click().perform()
 
-    def input(self, vals: Union[str, tuple], clear: bool = True, insure_input: bool = True) -> None:
-        """输入文本或组合键，也可用于输入文件路径到input元素（文件间用\n间隔）                  \n
+    def input(self,
+              vals: Union[str, tuple],
+              clear: bool = True,
+              insure_input: bool = True,
+              timeout: float = None) -> bool:
+        """输入文本或组合键，也可用于输入文件路径到input元素（文件间用\n间隔）                          \n
         :param vals: 文本值或按键组合
         :param clear: 输入前是否清空文本框
         :param insure_input: 确保输入正确，解决文本框有时输入失效的问题，不能用于输入组合键
-        :return: None
+        :param timeout: 尝试输入的超时时间，不指定则使用父页面的超时时间，只在insure_input为True时生效
+        :return: bool
         """
         if not insure_input:  # 普通输入
             if clear:
                 self.inner_ele.clear()
 
             self.inner_ele.send_keys(*vals)
+            return True
 
         else:  # 确保输入正确
             if not isinstance(vals, str):
@@ -359,14 +448,26 @@ class DriverElement(DrissionElement):
             full_txt = full_txt.rstrip('\n')
 
             self.click(by_js=True)
+            timeout = timeout if timeout is not None else self.page.timeout
             t1 = perf_counter()
-            while self.is_valid() and self.attr('value') != full_txt and perf_counter() - t1 <= self.page.timeout:
-                if clear:
-                    self.inner_ele.send_keys(u'\ue009', 'a', u'\ue017')  # 有些ui下clear()不生效，用CTRL+a代替
-                self.inner_ele.send_keys(vals)
+            while self.is_valid() and self.attr('value') != full_txt and perf_counter() - t1 <= timeout:
+                try:
+                    if clear:
+                        self.inner_ele.send_keys(u'\ue009', 'a', u'\ue017')  # 有些ui下clear()不生效，用CTRL+a代替
+                    self.inner_ele.send_keys(vals)
 
-            if enter:
-                self.inner_ele.send_keys(enter)
+                except Exception:
+                    pass
+
+            if not self.is_valid():
+                return False
+            else:
+                if self.attr('value') != full_txt:
+                    return False
+                else:
+                    if enter:
+                        self.inner_ele.send_keys(enter)
+                    return True
 
     def run_script(self, script: str, *args) -> Any:
         """执行js代码，传入自己为第一个参数  \n
@@ -376,13 +477,28 @@ class DriverElement(DrissionElement):
         """
         return self.inner_ele.parent.execute_script(script, self.inner_ele, *args)
 
-    def submit(self) -> None:
+    def submit(self) -> Union[bool, None]:
         """提交表单"""
-        self.inner_ele.submit()
+        try:
+            self.inner_ele.submit()
+            return True
+        except Exception:
+            pass
 
-    def clear(self) -> None:
-        """清空元素文本"""
-        self.input('')
+    def clear(self, insure_clear: bool = True) -> Union[None, bool]:
+        """清空元素文本                                    \n
+        :param insure_clear: 是否确保清空
+        :return: 是否清空成功，不能清空的元素返回None
+        """
+        if insure_clear:
+            return self.input('')
+
+        else:
+            try:
+                self.inner_ele.clear()
+                return True
+            except InvalidElementStateException:
+                return None
 
     def is_selected(self) -> bool:
         """是否选中"""
@@ -401,7 +517,7 @@ class DriverElement(DrissionElement):
         try:
             self.is_enabled()
             return True
-        except:
+        except Exception:
             return False
 
     def screenshot(self, path: str, filename: str = None) -> str:
@@ -445,30 +561,30 @@ class DriverElement(DrissionElement):
             value = value.replace("'", "\\'")
             self.run_script(f"arguments[0].{prop}='{value}';")
             return True
-        except:
+        except Exception:
             return False
 
     def set_attr(self, attr: str, value: str) -> bool:
-        """设置元素attribute参数          \n
-        :param attr: 参数名
-        :param value: 参数值
+        """设置元素attribute属性          \n
+        :param attr: 属性名
+        :param value: 属性值
         :return: 是否设置成功
         """
         try:
             self.run_script(f"arguments[0].setAttribute(arguments[1], arguments[2]);", attr, value)
             return True
-        except:
+        except Exception:
             return False
 
     def remove_attr(self, attr: str) -> bool:
-        """设置元素属性          \n
+        """删除元素attribute属性          \n
         :param attr: 属性名
-        :return: 是否设置成功
+        :return: 是否删除成功
         """
         try:
             self.run_script(f'arguments[0].removeAttribute("{attr}");')
             return True
-        except:
+        except Exception:
             return False
 
     def drag(self, x: int, y: int, speed: int = 40, shake: bool = True) -> bool:
@@ -529,10 +645,49 @@ class DriverElement(DrissionElement):
 
         return False if self.location == loc1 else True
 
-    def hover(self) -> None:
-        """鼠标悬停"""
+    def hover(self, x: int = None, y: int = None) -> None:
+        """鼠标悬停，可接受偏移量，偏移量相对于元素左上角坐标。不传入x或y值时悬停在元素中点    \n
+        :param x: 相对元素左上角坐标的x轴偏移量
+        :param y: 相对元素左上角坐标的y轴偏移量
+        :return: None
+        """
         from selenium.webdriver import ActionChains
-        ActionChains(self.page.driver).move_to_element(self.inner_ele).perform()
+        x = int(x) if x is not None else self.size['width'] // 2
+        y = int(y) if y is not None else self.size['height'] // 2
+        ActionChains(self.page.driver).move_to_element_with_offset(self.inner_ele, x, y).perform()
+
+    def _get_relative_eles(self,
+                           mode: str,
+                           loc: Union[tuple, str] = '') -> Union[List['DriverElement'], 'DriverElement']:
+        """获取网页上相对于当前元素周围的某个元素，可设置选取条件                          \n
+        :param mode: 可选：'left', 'right', 'above', 'below', 'near'
+        :param loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
+        :return: DriverElement对象
+        """
+        try:
+            from selenium.webdriver.support.relative_locator import RelativeBy
+        except ImportError:
+            raise ImportError('该方法只支持selenium4及以上版本。')
+
+        if isinstance(loc, str):
+            loc = str_to_loc(loc)
+
+        try:
+            if mode == 'left':
+                eles = self.page.driver.find_elements(RelativeBy({loc[0]: loc[1]}).to_left_of(self.inner_ele))
+            elif mode == 'right':
+                eles = self.page.driver.find_elements(RelativeBy({loc[0]: loc[1]}).to_right_of(self.inner_ele))
+            elif mode == 'above':
+                eles = self.page.driver.find_elements(RelativeBy({loc[0]: loc[1]}).above(self.inner_ele))
+            elif mode == 'below':
+                eles = self.page.driver.find_elements(RelativeBy({loc[0]: loc[1]}).below(self.inner_ele))
+            else:  # 'near'
+                eles = self.page.driver.find_elements(RelativeBy({loc[0]: loc[1]}).near(self.inner_ele))
+
+            return [self.page.ele(e) for e in eles]
+
+        except IndexError:
+            raise ValueError('未找到元素，请检查浏览器版本，低版本的浏览器无法使用此方法。')
 
 
 def make_driver_ele(page_or_ele,
@@ -548,12 +703,17 @@ def make_driver_ele(page_or_ele,
     :return: 返回DriverElement元素或它们组成的列表
     """
     # ---------------处理定位符---------------
-    if isinstance(loc, str):
-        loc = str_to_loc(loc)
-    elif isinstance(loc, tuple):
-        loc = translate_loc(loc)
+    if isinstance(loc, (str, tuple)):
+        loc = get_loc(loc)
+
+    elif str(type(loc)).endswith('RelativeBy'):
+        page = page_or_ele.page if isinstance(page_or_ele, BaseElement) else page_or_ele
+        driver = page.driver
+        eles = driver.find_elements(loc)
+        return DriverElement(eles[0], page) if single else [DriverElement(ele, page) for ele in eles]
+
     else:
-        raise ValueError("定位符必须为str或长度为2的tuple。")
+        raise ValueError("定位符必须为str、长度为2的tuple、或RelativeBy对象。")
 
     # ---------------设置 page 和 driver---------------
     if isinstance(page_or_ele, BaseElement):  # 传入DriverElement 或 ShadowRootElement
@@ -786,7 +946,7 @@ class Select(object):
                     raise ValueError('para_type参数只能传入"text"、"value"或"index"。')
                 return True
 
-            except:
+            except Exception:
                 return False
 
         elif isinstance(text_value_index, (list, tuple)):
@@ -899,7 +1059,7 @@ def _wait_ele(page_or_ele,
             if mode == 'del':
                 try:
                     loc_or_ele.is_enabled()
-                except:
+                except Exception:
                     return True
 
             elif mode == 'display' and loc_or_ele.is_displayed():
@@ -924,5 +1084,5 @@ def _wait_ele(page_or_ele,
 
             return True
 
-        except:
+        except Exception:
             return False
