@@ -7,7 +7,7 @@
 from glob import glob
 from os import sep
 from pathlib import Path
-from time import sleep
+from time import sleep, perf_counter
 from typing import Union, List, Any, Tuple
 from urllib.parse import quote
 
@@ -87,7 +87,7 @@ class DriverPage(BasePage):
 
         try:
             self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => undefined,});')
-        except:
+        except Exception:
             pass
 
         return self._url_available
@@ -95,9 +95,9 @@ class DriverPage(BasePage):
     def ele(self,
             loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
             timeout: float = None) -> Union[DriverElement, List[DriverElement], str, None]:
-        """返回页面中符合条件的第一个元素                                                           \n
+        """返回页面中符合条件的第一个元素                                          \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: DriverElement对象或属性、文本
         """
         return self._ele(loc_or_ele, timeout)
@@ -105,21 +105,24 @@ class DriverPage(BasePage):
     def eles(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout: float = None) -> List[DriverElement]:
-        """返回页面中所有符合条件的元素                                                                     \n
+        """返回页面中所有符合条件的元素                                     \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: DriverElement对象或属性、文本组成的列表
         """
         return self._ele(loc_or_str, timeout, single=False)
 
-    def s_ele(self, loc_or_ele):
+    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, DriverElement] = None):
         """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高       \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
-        return make_session_ele(self, loc_or_ele)
+        if isinstance(loc_or_ele, DriverElement):
+            return make_session_ele(loc_or_ele)
+        else:
+            return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str]):
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None):
         """查找所有符合条件的元素以SessionElement列表形式返回                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象组成的列表
@@ -150,7 +153,7 @@ class DriverPage(BasePage):
 
         # 接收到的类型不正确，抛出异常
         else:
-            raise ValueError('loc_or_str参数只能是tuple、str、DriverElement 或 DriverElement类型。')
+            raise ValueError('loc_or_str参数只能是tuple、str、DriverElement 或 WebElement类型。')
 
     def get_cookies(self, as_dict: bool = False) -> Union[list, dict]:
         """返回当前网站cookies"""
@@ -225,7 +228,7 @@ class DriverPage(BasePage):
         """返回标签页数量"""
         try:
             return len(self.driver.window_handles)
-        except:
+        except Exception:
             return 0
 
     @property
@@ -234,7 +237,7 @@ class DriverPage(BasePage):
         return self.driver.window_handles
 
     @property
-    def current_tab_num(self) -> int:
+    def current_tab_index(self) -> int:
         """返回当前标签页序号"""
         return self.driver.window_handles.index(self.driver.current_window_handle)
 
@@ -243,6 +246,11 @@ class DriverPage(BasePage):
         """返回当前标签页handle"""
         return self.driver.current_window_handle
 
+    @property
+    def active_ele(self) -> DriverElement:
+        """返回当前焦点所在元素"""
+        return DriverElement(self.driver.switch_to.active_element, self)
+
     def wait_ele(self,
                  loc_or_ele: Union[str, tuple, DriverElement, WebElement],
                  mode: str,
@@ -274,9 +282,14 @@ class DriverPage(BasePage):
         :param url: 新标签页跳转到的网址
         :return: None
         """
-        self.to_tab(-1)
-        self.run_script(f'window.open("{url}");')
-        self.to_tab(-1)
+        try:  # selenium4新增功能，须配合新版浏览器
+            self.driver.switch_to.new_window('tab')
+            if url:
+                self.get(url)
+        except Exception:
+            self.to_tab(-1)
+            self.run_script(f'window.open("{url}");')
+            self.to_tab(-1)
 
     def close_current_tab(self) -> None:
         """关闭当前标签页"""
@@ -328,7 +341,7 @@ class DriverPage(BasePage):
         tab = self.driver.window_handles[tab] if isinstance(tab, int) else tab
         self.driver.switch_to.window(tab)
 
-    def to_frame(self, loc_or_ele: Union[int, str, tuple, WebElement, DriverElement] = 'main') -> None:
+    def to_frame(self, loc_or_ele: Union[int, str, tuple, WebElement, DriverElement] = 'main') -> 'DriverPage':
         """跳转到frame                                                                       \n
         可接收frame序号(0开始)、id或name、查询字符串、loc元组、WebElement对象、DriverElement对象，  \n
         传入 'main' 跳到最高层，传入 'parent' 跳到上一层                                             \n
@@ -341,7 +354,7 @@ class DriverPage(BasePage):
             to_frame('main')          - 跳到最高层                                              \n
             to_frame('parent')        - 跳到上一层                                              \n
         :param loc_or_ele: iframe的定位信息
-        :return: None
+        :return: 返回自己，用于链式操作
         """
         # 根据序号跳转
         if isinstance(loc_or_ele, int):
@@ -375,6 +388,8 @@ class DriverPage(BasePage):
             ele = self.ele(loc_or_ele)
             self.driver.switch_to.frame(ele.inner_ele)
 
+        return self
+
     def screenshot(self, path: str, filename: str = None) -> str:
         """截取页面可见范围截图                                  \n
         :param path: 保存路径
@@ -477,18 +492,20 @@ class DriverPage(BasePage):
         :param mode: 'ok' 或 'cancel'，若输入其它值，不会按按钮但依然返回文本值
         :param text: 处理prompt提示框时可输入文本
         :param timeout: 等待提示框出现的超时时间
-        :return: 提示框内容文本
+        :return: 提示框内容文本，未等到提示框则返回None
         """
-        timeout = timeout if timeout is not None else self.timeout
-        from time import perf_counter
-        alert = None
-        t1 = perf_counter()
-        while perf_counter() - t1 <= timeout:
+
+        def do_it():
             try:
-                alert = self.driver.switch_to.alert
-                break
+                return self.driver.switch_to.alert
             except NoAlertPresentException:
-                pass
+                return False
+
+        timeout = timeout if timeout is not None else self.timeout
+        t1 = perf_counter()
+        alert = do_it()
+        while not alert and perf_counter() - t1 <= timeout:
+            alert = do_it()
 
         if not alert:
             return None
