@@ -122,9 +122,9 @@ class MixPage(SessionPage, DriverPage, BasePage):
             loc_or_ele: Union[Tuple[str, str], str, DriverElement, SessionElement, WebElement],
             timeout: float = None) \
             -> Union[DriverElement, SessionElement, str, List[SessionElement], List[DriverElement]]:
-        """返回第一个符合条件的元素、属性或节点文本                                               \n
+        """返回第一个符合条件的元素、属性或节点文本                               \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: 元素对象或属性、文本节点文本
         """
         if self._mode == 's':
@@ -137,7 +137,7 @@ class MixPage(SessionPage, DriverPage, BasePage):
              timeout: float = None) -> Union[List[DriverElement], List[SessionElement], List[str]]:
         """返回页面中所有符合条件的元素、属性或节点文本                                \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
+        :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: 元素对象或属性、文本组成的列表
         """
         if self._mode == 's':
@@ -402,16 +402,16 @@ class MixPage(SessionPage, DriverPage, BasePage):
                 'download.default_directory']
             if not path:
                 raise ValueError('未指定下载路径。')
-        except:
+        except Exception:
             raise IOError('无法找到下载路径。')
 
         return super().chrome_downloading(path)
 
     # ----------------MixPage独有函数-----------------------
-    def hide_browser(self):
+    def hide_browser(self) -> None:
         """隐藏浏览器窗口"""
         self.drission.hide_browser()
 
-    def show_browser(self):
+    def show_browser(self) -> None:
         """显示浏览器窗口"""
         self.drission.show_browser()
