@@ -12,23 +12,28 @@ from lxml.etree import tostring
 from lxml.html import HtmlElement, fromstring
 
 from .base import DrissionElement, BasePage, BaseElement
-from .common import str_to_loc, translate_loc, get_ele_txt
+from .common import get_ele_txt, get_loc
 
 
 class SessionElement(DrissionElement):
     """session模式的元素对象，包装了一个lxml的Element对象，并封装了常用功能"""
 
     def __init__(self, ele: HtmlElement, page=None):
+        """初始化对象                                                          \n
+        :param ele: 被包装的HtmlElement元素
+        :param page: 元素所在页面对象，如果是从 html 文本生成的元素，则为 None
+        """
         super().__init__(ele, page)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
         return f'<SessionElement {self.tag} {" ".join(attrs)}>'
 
-    def __call__(self, loc_or_str: Union[Tuple[str, str], str]):
-        """在内部查找元素                                            \n
-        例：ele2 = ele1('@id=ele_id')                              \n
+    def __call__(self, loc_or_str: Union[Tuple[str, str], str], timeout=None):
+        """在内部查找元素                                                  \n
+        例：ele2 = ele1('@id=ele_id')                                    \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
         :return: SessionElement对象或属性、文本
         """
         return self.ele(loc_or_str)
@@ -65,18 +70,6 @@ class SessionElement(DrissionElement):
         """返回未格式化处理的元素内文本"""
         return str(self._inner_ele.text_content())
 
-    @property
-    def parent(self):
-        """返回父级元素"""
-        return self.parents()
-
-    def parents(self, num: int = 1):
-        """返回上面第num级父元素                                         \n
-        :param num: 第几级父元素
-        :return: SessionElement对象
-        """
-        return self.ele(f'xpath:..{"/.." * (num - 1)}')
-
     def attr(self, attr: str) -> Union[str, None]:
         """返回attribute属性值                           \n
         :param attr: 属性名
@@ -133,7 +126,7 @@ class SessionElement(DrissionElement):
         """
         return self._ele(loc_or_str)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str]):
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None):
         """返回当前元素下级所有符合条件的子元素、属性或节点文本                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本组成的列表
@@ -165,9 +158,9 @@ class SessionElement(DrissionElement):
                 brothers = len(ele.eles(f'xpath:./preceding-sibling::{ele.tag}'))
                 path_str = f'/{ele.tag}[{brothers + 1}]{path_str}' if brothers > 0 else f'/{ele.tag}{path_str}'
 
-            ele = ele.parent
+            ele = ele.parent()
 
-        return path_str[1:] if mode == 'css' else path_str
+        return f':root{path_str[1:]}' if mode == 'css' else path_str
 
     # ----------------session独有方法-----------------------
     def _make_absolute(self, link) -> str:
@@ -206,12 +199,14 @@ def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
     """
     # ---------------处理定位符---------------
     if not loc:
+        if isinstance(html_or_ele, SessionElement):
+            return html_or_ele if single else [html_or_ele]
+
         loc = ('xpath', '.')
-        single = True
-    elif isinstance(loc, str):
-        loc = str_to_loc(loc)
-    elif isinstance(loc, tuple):
-        loc = translate_loc(loc)
+
+    elif isinstance(loc, (str, tuple)):
+        loc = get_loc(loc)
+
     else:
         raise ValueError("定位符必须为str或长度为2的tuple。")
 
