@@ -30,11 +30,12 @@ class SessionPage(BasePage):
         self._session = session
         self._response = None
 
-    def __call__(self, loc_or_str: Union[Tuple[str, str], str, SessionElement]) \
+    def __call__(self, loc_or_str: Union[Tuple[str, str], str, SessionElement], timeout=None) \
             -> Union[SessionElement, List[SessionElement], str]:
-        """在内部查找元素                                            \n
-        例：ele2 = ele1('@id=ele_id')                              \n
+        """在内部查找元素                                                  \n
+        例：ele2 = ele1('@id=ele_id')                                     \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
         :return: SessionElement对象或属性文本
         """
         return self.ele(loc_or_str)
@@ -96,7 +97,7 @@ class SessionPage(BasePage):
 
         return self._url_available
 
-    def ele(self, loc_or_ele: Union[Tuple[str, str], str, SessionElement], timeout=None) \
+    def ele(self, loc_or_ele: Union[Tuple[str, str], str, SessionElement], timeout: float = None) \
             -> Union[SessionElement, List[SessionElement], str, None]:
         """返回页面中符合条件的第一个元素、属性或节点文本                            \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
@@ -105,7 +106,7 @@ class SessionPage(BasePage):
         """
         return self._ele(loc_or_ele)
 
-    def eles(self, loc_or_str: Union[Tuple[str, str], str], timeout=None) -> List[SessionElement]:
+    def eles(self, loc_or_str: Union[Tuple[str, str], str], timeout: float = None) -> List[SessionElement]:
         """返回页面中所有符合条件的元素、属性或节点文本                          \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
@@ -113,14 +114,14 @@ class SessionPage(BasePage):
         """
         return self._ele(loc_or_str, single=False)
 
-    def s_ele(self, loc_or_str: Union[Tuple[str, str], str]):
+    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, SessionElement] = None):
         """返回页面中符合条件的第一个元素、属性或节点文本                          \n
-        :param loc_or_str: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
+        :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
-        return self._ele(loc_or_str)
+        return make_session_ele(self.html) if loc_or_ele is None else self._ele(loc_or_ele)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str]):
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None):
         """返回页面中符合条件的所有元素、属性或节点文本                              \n
         :param loc_or_str: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
